==> uhub-0.1.4-2301-src.tar.gz: uhub-0.1.4-2301/src/hub.h <==
/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef HAVE_UHUB_HUB_H
#define HAVE_UHUB_HUB_H




struct hub_info
{
	int fd;
	struct event ev_accept;
	struct event ev_timer;
	struct hub_config* config;
	struct linked_list* user_list;
	sid_t free_sid;
	struct acl_handle* acl;
	struct adc_message* command_info;
	struct adc_message* command_motd;
	struct adc_message* command_support;
	struct adc_message* command_banner;
	struct adc_message* command_error_hub_full;
	struct adc_message* command_error_hub_disabled;
	struct adc_message* command_error_nick_missing;
	struct adc_message* command_error_nick_invalid;
	struct adc_message* command_error_nick_taken;
	struct adc_message* command_error_cid_missing;
	struct adc_message* command_error_cid_invalid;
	struct adc_message* command_error_cid_taken;
	struct adc_message* command_error_pid_missing;
	struct adc_message* command_ban_perm;
	struct adc_message* command_ban_temp;
	struct adc_message* command_registered_only;
	struct adc_message* command_password_wrong;
	time_t tm_started;
	int flag_restart;
};

/**
 * This is the message pre-routing centre.
 *
 * Any message coming in to the hub comes through here first,
 * and will be routed further if valid.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_message(struct hub_info* hub, struct user* u, const char* message);


/**
 * Handle protocol support/subscription messages received clients.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_support(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Handle password messages received from clients.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_password(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Handle info messages as received from clients.
 * This can be an initial info message, which might end up requiring password
 * authentication, etc.
 * All sorts of validation is performed here.
 * - Nickname valid?
 * - CID/PID valid?
 * - Network IP address valid?
 *
 * This can be triggered multiple times, as users can update their information,
 * in such case nickname and CID/PID changes are not allowed.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_info(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Used internally by hub_handle_info
 * @return 1 if nickname is OK, or 0 if nickname is not accepted.
 */
extern int  hub_handle_info_check_nick(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Used internally by hub_handle_info
 * @return 1 if CID/PID is OK, or 0 if not valid.
 */
extern int  hub_handle_info_check_cid(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Can only be used by administrators or operators.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_kick(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Send the support line for the hub to a particular user.
 * Only used during the initial handshake.
 */
extern void hub_send_support(struct hub_info* hub, struct user* u);

/**
 * Send a message assigning a SID for a user.
 * This is only sent after hub_send_support() during initial handshake.
 */
extern void hub_send_sid(struct hub_info* hub, struct user* u);

/**
 * Send a message containing hub information to a particular user.
 * This is sent during user connection, but can safely be sent at any
 * point later.
 */
extern void hub_send_hubinfo(struct hub_info* hub, struct user* u);

/**
 * Send handshake. This basically calls
 * hub_send_support() and hub_send_sid()
 */
extern void hub_send_handshake(struct hub_info* hub, struct user* u);

/**
 * Send a welcome message containing the message of the day to 
 * one particular user. This can be sent in any point in time.
 */
extern void hub_send_motd(struct hub_info* hub, struct user* u);

/**
 * Send a password challenge to a user.
 * This is only used if the user tries to access the hub using a
 * password protected nick name.
 */
extern void hub_send_password_challenge(struct hub_info* hub, struct user* u);


/**
 * This starts the hub.
 */
extern struct hub_info* hub_start_service(struct hub_config* config);

/**
 * This shuts down the hub.
 */
extern void hub_shutdown_service(struct hub_info* hub);

/**
 * This configures the hub.
 */
extern void hub_set_variables(struct hub_info* hub, struct acl_handle* acl);

/**
 * This frees the configuration of the hub.
 */
extern void hub_free_variables(struct hub_info* hub);


#endif /* HAVE_UHUB_HUB_H */

==> uhub-0.1.6-2608-src.tar.gz: uhub-0.1.6-2608/src/hub.h <==
/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef HAVE_UHUB_HUB_H
#define HAVE_UHUB_HUB_H

enum hub_state {
	hub_status_uninitialized = 0, /**<<<"Hub is uninitialized" */
	hub_status_running       = 1, /**<<<"Hub is running (normal operation)" */
	hub_status_restart       = 2, /**<<<"Hub is restarting (re-reading configuration, etc)" */
	hub_status_shutdown      = 3, /**<<<"Hub is shutting down, but not yet stopped. */
	hub_status_stopped       = 4, /**<<<"Hub is stopped (Pretty much the same as initialized) */
	hub_status_disabled      = 5, /**<<<"Hub is disabled (Running, but not accepting users) */
};

struct hub_info
{
	int fd_tcp;
	int fd_udp;
	struct event ev_accept;
	struct event ev_timer;
	struct event ev_datagram;
	struct hub_config* config;
	struct linked_list* user_list;
	sid_t free_sid;
	struct acl_handle* acl;
	struct adc_message* command_info;
	struct adc_message* command_motd;
	struct adc_message* command_support;
	struct adc_message* command_banner;
	struct adc_message* command_error_hub_full;
	struct adc_message* command_error_hub_disabled;
	struct adc_message* command_error_nick_missing;
	struct adc_message* command_error_nick_invalid;
	struct adc_message* command_error_nick_taken;
	struct adc_message* command_error_cid_missing;
	struct adc_message* command_error_cid_invalid;
	struct adc_message* command_error_cid_taken;
	struct adc_message* command_error_pid_missing;
	struct adc_message* command_ban_perm;
	struct adc_message* command_ban_temp;
	struct adc_message* command_registered_only;
	struct adc_message* command_password_wrong;
	struct adc_message* command_ping;
	time_t tm_started;
	int status;
#ifdef SSL_SUPPORT
	SSL_METHOD* ssl_method;
	SSL_CTX* ssl_ctx;
#endif /*  SSL_SUPPORT */
};

/**
 * This is the message pre-routing centre.
 *
 * Any message coming in to the hub comes through here first,
 * and will be routed further if valid.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_message(struct hub_info* hub, struct user* u, const char* message, size_t length);


/**
 * Handle protocol support/subscription messages received clients.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_support(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Handle password messages received from clients.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_password(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Handle info messages as received from clients.
 * This can be an initial info message, which might end up requiring password
 * authentication, etc.
 * All sorts of validation is performed here.
 * - Nickname valid?
 * - CID/PID valid?
 * - Network IP address valid?
 *
 * This can be triggered multiple times, as users can update their information,
 * in such case nickname and CID/PID changes are not allowed.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_info(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Used internally by hub_handle_info
 * @return 1 if nickname is OK, or 0 if nickname is not accepted.
 */
extern int  hub_handle_info_check_nick(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Used internally by hub_handle_info
 * @return 1 if CID/PID is OK, or 0 if not valid.
 */
extern int  hub_handle_info_check_cid(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Can only be used by administrators or operators.
 *
 * @return 0 on success, -1 on error
 */
extern int hub_handle_kick(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Handle incoming autocheck message.
 */
extern int hub_handle_autocheck(struct hub_info* hub, struct user* u, struct adc_message* cmd);

/**
 * Send the support line for the hub to a particular user.
 * Only used during the initial handshake.
 */
extern void hub_send_support(struct hub_info* hub, struct user* u);

/**
 * Send a message assigning a SID for a user.
 * This is only sent after hub_send_support() during initial handshake.
 */
extern void hub_send_sid(struct hub_info* hub, struct user* u);

/**
 * Send a message containing hub information to a particular user.
 * This is sent during user connection, but can safely be sent at any
 * point later.
 */
extern void hub_send_hubinfo(struct hub_info* hub, struct user* u);

/**
 * Send handshake. This basically calls
 * hub_send_support() and hub_send_sid()
 */
extern void hub_send_handshake(struct hub_info* hub, struct user* u);

/**
 * Send a welcome message containing the message of the day to 
 * one particular user. This can be sent in any point in time.
 */
extern void hub_send_motd(struct hub_info* hub, struct user* u);

/**
 * Send a password challenge to a user.
 * This is only used if the user tries to access the hub using a
 * password protected nick name.
 */
extern void hub_send_password_challenge(struct hub_info* hub, struct user* u);

/**
 * Send an autocheck message to a user.
 * This is basically a UDP message. The user's client can then determine
 * if UDP communication works by either hole punching or configuring UPnP.
 */
extern void hub_send_autocheck(struct hub_info* hub, struct user* u, uint16_t port, const char* token);

/**
 * This starts the hub.
 */
extern struct hub_info* hub_start_service(struct hub_config* config);

/**
 * This shuts down the hub.
 */
extern void hub_shutdown_service(struct hub_info* hub);

/**
 * This configures the hub.
 */
extern void hub_set_variables(struct hub_info* hub, struct acl_handle* acl);

/**
 * This frees the configuration of the hub.
 */
extern void hub_free_variables(struct hub_info* hub);


#endif /* HAVE_UHUB_HUB_H */
